@@ -4,12 +4,18 @@ from datetime import datetime
 import requests
 
 from nicovideo_api_client.api.v2.targets import SnapshotSearchAPIV2Targets
-from nicovideo_api_client.constants import END_POINT_URL_V2_VERSION, FieldType, target_types
+from nicovideo_api_client.constants import (
+    END_POINT_URL_V2_VERSION,
+    FieldType,
+    target_types,
+)
 
 
 class SnapshotSearchAPIV2:
     """
-    `ニコニコ動画 『スナップショット検索API v2』 <https://site.nicovideo.jp/search-api-docs/snapshot>`_ のエンドポイント
+    `ニコニコ動画 『スナップショット検索API v2』 <https://site.nicovideo.jp/search-api-docs/snapshot>`_
+    のエンドポイント
+
     ここの関数から返るオブジェクトをメソッドチェーンをつないで呼び出すことで適切に設定された状態でAPIを叩くことができる。
     """
 
@@ -29,7 +35,9 @@ class SnapshotSearchAPIV2:
 
         :return: クエリ(キーワード)入力オブジェクト
         """
-        return SnapshotSearchAPIV2Targets(FieldType.TITLE, FieldType.DESCRIPTION, FieldType.TAGS)
+        return SnapshotSearchAPIV2Targets(
+            FieldType.TITLE, FieldType.DESCRIPTION, FieldType.TAGS
+        )
 
     @staticmethod
     def targets(targets: Set[FieldType]) -> SnapshotSearchAPIV2Targets:
